@@ -9,14 +9,13 @@ import lazy_loader as lazy
 # No more pandas warnings
 from pandas.plotting import register_matplotlib_converters
 
-from . import tests
 from ._version import get_versions
 
+register_matplotlib_converters()
+
 # Import early so these classes are available to the object
 from .qc import QCFilter, QCTests, clean
 
-register_matplotlib_converters()
-
 # Import the lazy loaded modules
 submodules = [
     'corrections',
@@ -26,6 +25,7 @@ submodules = [
     'utils',
     'retrievals',
     'plotting',
+    'tests',
 ]
 __getattr__, __dir__, _ = lazy.attach(__name__, submodules)
 
