@@ -50,11 +50,11 @@ class SkewTDisplay(Display):
 
     """
 
-    def __init__(self, obj, subplot_shape=(1,), ds_name=None, **kwargs):
+    def __init__(self, ds, subplot_shape=(1,), ds_name=None, **kwargs):
         # We want to use our routine to handle subplot adding, not the main
         # one
         new_kwargs = kwargs.copy()
-        super().__init__(obj, None, ds_name, subplot_kw=dict(projection='skewx'), **new_kwargs)
+        super().__init__(ds, None, ds_name, subplot_kw=dict(projection='skewx'), **new_kwargs)
 
         # Make a SkewT object for each subplot
         self.add_subplots(subplot_shape, **kwargs)
@@ -191,30 +191,30 @@ class SkewTDisplay(Display):
             The matplotlib axis handle corresponding to the plot.
 
         """
-        if dsname is None and len(self._obj.keys()) > 1:
+        if dsname is None and len(self._ds.keys()) > 1:
             raise ValueError(
                 'You must choose a datastream when there are 2 '
                 'or more datasets in the TimeSeriesDisplay '
                 'object.'
             )
         elif dsname is None:
-            dsname = list(self._obj.keys())[0]
+            dsname = list(self._ds.keys())[0]
 
         # Make temporary field called tempu, tempv
-        spd = self._obj[dsname][spd_field].values
-        dir = self._obj[dsname][dir_field].values
+        spd = self._ds[dsname][spd_field].values
+        dir = self._ds[dsname][dir_field].values
         with warnings.catch_warnings():
             warnings.filterwarnings('ignore', category=RuntimeWarning)
             tempu = -np.sin(np.deg2rad(dir)) * spd
             tempv = -np.cos(np.deg2rad(dir)) * spd
-        self._obj[dsname]['temp_u'] = deepcopy(self._obj[dsname][spd_field])
-        self._obj[dsname]['temp_v'] = deepcopy(self._obj[dsname][spd_field])
-        self._obj[dsname]['temp_u'].values = tempu
-        self._obj[dsname]['temp_v'].values = tempv
+        self._ds[dsname]['temp_u'] = deepcopy(self._ds[dsname][spd_field])
+        self._ds[dsname]['temp_v'] = deepcopy(self._ds[dsname][spd_field])
+        self._ds[dsname]['temp_u'].values = tempu
+        self._ds[dsname]['temp_v'].values = tempv
         the_ax = self.plot_from_u_and_v(
             'temp_u', 'temp_v', p_field, t_field, td_field, dsname, **kwargs
         )
-        del self._obj[dsname]['temp_u'], self._obj[dsname]['temp_v']
+        del self._ds[dsname]['temp_u'], self._ds[dsname]['temp_v']
         return the_ax
 
     def plot_from_u_and_v(
@@ -288,14 +288,14 @@ class SkewTDisplay(Display):
             The axis handle to the plot.
 
         """
-        if dsname is None and len(self._obj.keys()) > 1:
+        if dsname is None and len(self._ds.keys()) > 1:
             raise ValueError(
                 'You must choose a datastream when there are 2 '
                 'or more datasets in the TimeSeriesDisplay '
                 'object.'
             )
         elif dsname is None:
-            dsname = list(self._obj.keys())[0]
+            dsname = list(self._ds.keys())[0]
 
         if p_levels_to_plot is None:
             p_levels_to_plot = np.array(
@@ -318,34 +318,34 @@ class SkewTDisplay(Display):
             ) * units('hPa')
 
         # Get pressure and smooth if not in order
-        p = self._obj[dsname][p_field]
+        p = self._ds[dsname][p_field]
         if not all(p[i] <= p[i + 1] for i in range(len(p) - 1)):
-            self._obj[dsname][p_field] = (
-                self._obj[dsname][p_field].rolling(time=smooth_p, min_periods=1, center=True).mean()
+            self._ds[dsname][p_field] = (
+                self._ds[dsname][p_field].rolling(time=smooth_p, min_periods=1, center=True).mean()
             )
-            p = self._obj[dsname][p_field]
+            p = self._ds[dsname][p_field]
 
-        p_units = self._obj[dsname][p_field].attrs['units']
+        p_units = self._ds[dsname][p_field].attrs['units']
         p = p.values * getattr(units, p_units)
 
-        T = self._obj[dsname][t_field]
-        T_units = self._obj[dsname][t_field].attrs['units']
+        T = self._ds[dsname][t_field]
+        T_units = self._ds[dsname][t_field].attrs['units']
         if T_units == 'C':
             T_units = 'degC'
 
         T = T.values * getattr(units, T_units)
-        Td = self._obj[dsname][td_field]
-        Td_units = self._obj[dsname][td_field].attrs['units']
+        Td = self._ds[dsname][td_field]
+        Td_units = self._ds[dsname][td_field].attrs['units']
         if Td_units == 'C':
             Td_units = 'degC'
 
         Td = Td.values * getattr(units, Td_units)
-        u = self._obj[dsname][u_field]
-        u_units = self._obj[dsname][u_field].attrs['units']
+        u = self._ds[dsname][u_field]
+        u_units = self._ds[dsname][u_field].attrs['units']
         u = u.values * getattr(units, u_units)
 
-        v = self._obj[dsname][v_field]
-        v_units = self._obj[dsname][v_field].attrs['units']
+        v = self._ds[dsname][v_field]
+        v_units = self._ds[dsname][v_field].attrs['units']
         v = v.values * getattr(units, v_units)
 
         u_red = np.zeros_like(p_levels_to_plot) * getattr(units, u_units)
@@ -397,7 +397,7 @@ class SkewTDisplay(Display):
                 [
                     dsname,
                     'on',
-                    dt_utils.numpy_to_arm_date(self._obj[dsname].time.values[0]),
+                    dt_utils.numpy_to_arm_date(self._ds[dsname].time.values[0]),
                 ]
             )
 
