@@ -15,14 +15,14 @@ from act.utils.geo_utils import get_solar_azimuth_elevation
 from act.utils.data_utils import convert_units
 
 
-def _calculate_solar_parameters(obj, lat_name, lon_name, solar_constant):
+def _calculate_solar_parameters(ds, lat_name, lon_name, solar_constant):
     """
     Function to calculate solar zenith angles and solar constant adjusted
     to Earth Sun distance
 
     Parameters
     ----------
-    obj : Xarray.Dataset
+    ds : xarray.Dataset
         Dataset containing location variables
     lat_name : str
         Variable name for latitude
@@ -36,16 +36,16 @@ def _calculate_solar_parameters(obj, lat_name, lon_name, solar_constant):
     Tuple containing (solar zenith angle array, solar constant scalar)
 
     """
-    latitude = obj[lat_name].values
+    latitude = ds[lat_name].values
     if latitude.size > 1:
         latitude = latitude[0]
-    longitude = obj[lon_name].values
+    longitude = ds[lon_name].values
     if longitude.size > 1:
         longitude = longitude[0]
 
     # Calculate solar parameters
     elevation, _, solar_distance = get_solar_azimuth_elevation(
-        latitude=latitude, longitude=longitude, time=obj['time'].values)
+        latitude=latitude, longitude=longitude, time=ds['time'].values)
     solar_distance = np.nanmean(solar_distance)
     Sa = solar_constant / solar_distance**2
 
@@ -54,13 +54,13 @@ def _calculate_solar_parameters(obj, lat_name, lon_name, solar_constant):
     return (sza, Sa)
 
 
-def _find_indexes(obj, var_name, min_limit, max_limit, use_dask):
+def _find_indexes(ds, var_name, min_limit, max_limit, use_dask):
     """
     Function to find array indexes where failing limit tests
 
     Parameters
     ----------
-    obj : Xarray.Dataset
+    ds : xarray.Dataset
         Dataset containing data to use in test
     var_name : str
         Variable name to inspect
@@ -78,12 +78,12 @@ def _find_indexes(obj, var_name, min_limit, max_limit, use_dask):
     """
     with warnings.catch_warnings():
         warnings.filterwarnings('ignore', category=RuntimeWarning)
-        if use_dask and isinstance(obj[var_name].data, da.Array):
-            index_min = da.where(obj[var_name].data < min_limit, True, False).compute()
-            index_max = da.where(obj[var_name].data > max_limit, True, False).compute()
+        if use_dask and isinstance(ds[var_name].data, da.Array):
+            index_min = da.where(ds[var_name].data < min_limit, True, False).compute()
+            index_max = da.where(ds[var_name].data > max_limit, True, False).compute()
         else:
-            index_min = np.less(obj[var_name].values, min_limit)
-            index_max = np.greater(obj[var_name].values, max_limit)
+            index_min = np.less(ds[var_name].values, min_limit)
+            index_max = np.greater(ds[var_name].values, max_limit)
 
     return (index_min, index_max)
 
@@ -91,7 +91,7 @@ def _find_indexes(obj, var_name, min_limit, max_limit, use_dask):
 class QCTests:
     """
     This is a Mixins class used to allow using qcfilter class that is already
-    registered to the xarray object. All the methods in this class will be added
+    registered to the Xarray dataset. All the methods in this class will be added
     to the qcfilter class. Doing this to make the code spread across more files
     so it is more manageable and readable. Additinal files of tests can be added
     to qcfilter by creating a new class in the new file and adding to qcfilter
@@ -174,8 +174,8 @@ class QCTests:
         --------
             .. code-block:: python
 
-                ds_object = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_BRS, cleanup_qc=True)
-                ds_object.qcfilter.bsrn_limits_test(
+                ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_BRS, cleanup_qc=True)
+                ds.qcfilter.bsrn_limits_test(
                     gbl_SW_dn_name='down_short_hemisp',
                     glb_diffuse_SW_dn_name='down_short_diffuse_hemisp',
                     direct_normal_SW_dn_name='short_direct_normal',
@@ -191,7 +191,7 @@ class QCTests:
             raise ValueError(f"Value of '{test}' in keyword 'test' not recognized. "
                              f"Must a single value in options {test_names_org}")
 
-        sza, Sa = _calculate_solar_parameters(self._obj, lat_name, lon_name, solar_constant)
+        sza, Sa = _calculate_solar_parameters(self._ds, lat_name, lon_name, solar_constant)
 
         if test == test_names[0]:
             if sw_min_limit is None:
@@ -225,13 +225,13 @@ class QCTests:
             elif test == test_names[1]:
                 sw_max_limit = Sa * 1.2 * cos_sza**1.2 + 50.
 
-            index_min, index_max = _find_indexes(self._obj, gbl_SW_dn_name, sw_min_limit, sw_max_limit, use_dask)
+            index_min, index_max = _find_indexes(self._ds, gbl_SW_dn_name, sw_min_limit, sw_max_limit, use_dask)
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 gbl_SW_dn_name, index=index_min, test_assessment='Bad',
                 test_meaning=f"Value less than BSRN {test.lower()} limit of {sw_min_limit} W/m^2")
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 gbl_SW_dn_name, index=index_max, test_assessment='Bad',
                 test_meaning=f"Value greater than BSRN {test.lower()} limit")
 
@@ -244,13 +244,13 @@ class QCTests:
                 elif test == test_names[1]:
                     sw_max_limit = Sa * 0.75 * np.cos(np.radians(sza))**1.2 + 30.
 
-            index_min, index_max = _find_indexes(self._obj, glb_diffuse_SW_dn_name, sw_min_limit,
+            index_min, index_max = _find_indexes(self._ds, glb_diffuse_SW_dn_name, sw_min_limit,
                                                  sw_max_limit, use_dask)
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_diffuse_SW_dn_name, index=index_min, test_assessment='Bad',
                 test_meaning=f"Value less than BSRN {test.lower()} limit of {sw_min_limit} W/m^2")
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_diffuse_SW_dn_name, index=index_max, test_assessment='Bad',
                 test_meaning=f"Value greater than BSRN {test.lower()} limit")
 
@@ -263,13 +263,13 @@ class QCTests:
                 elif test == test_names[1]:
                     sw_max_limit = Sa * 0.95 * np.cos(np.radians(sza))**0.2 + 10.
 
-            index_min, index_max = _find_indexes(self._obj, direct_normal_SW_dn_name,
+            index_min, index_max = _find_indexes(self._ds, direct_normal_SW_dn_name,
                                                  sw_min_limit, sw_max_limit, use_dask)
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 direct_normal_SW_dn_name, index=index_min, test_assessment='Bad',
                 test_meaning=f"Value less than BSRN {test.lower()} limit of {sw_min_limit} W/m^2")
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 direct_normal_SW_dn_name, index=index_max, test_assessment='Bad',
                 test_meaning=f"Value greater than BSRN {test.lower()} limit")
 
@@ -282,14 +282,14 @@ class QCTests:
                 elif test == test_names[1]:
                     sw_max_limit = Sa * 0.95 * np.cos(np.radians(sza))**1.2 + 10
 
-            index_min, index_max = _find_indexes(self._obj, direct_SW_dn_name,
+            index_min, index_max = _find_indexes(self._ds, direct_SW_dn_name,
                                                  sw_min_limit, sw_max_limit, use_dask)
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 direct_SW_dn_name, index=index_min, test_assessment='Bad',
                 test_meaning=f"Value less than BSRN {test.lower()} limit of {sw_min_limit} W/m^2")
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 direct_SW_dn_name, index=index_max, test_assessment='Bad',
                 test_meaning=f"Value greater than BSRN {test.lower()} limit")
 
@@ -302,40 +302,40 @@ class QCTests:
                 elif test == test_names[1]:
                     sw_max_limit = Sa * np.cos(np.radians(sza))**1.2 + 50
 
-            index_min, index_max = _find_indexes(self._obj, glb_SW_up_name,
+            index_min, index_max = _find_indexes(self._ds, glb_SW_up_name,
                                                  sw_min_limit, sw_max_limit, use_dask)
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_SW_up_name, index=index_min, test_assessment='Bad',
                 test_meaning=f"Value less than BSRN {test.lower()} limit of {sw_min_limit} W/m^2")
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_SW_up_name, index=index_max, test_assessment='Bad',
                 test_meaning=f"Value greater than BSRN {test.lower()} limit")
 
         # Longwave downwelling min and max tests
         if glb_LW_dn_name is not None:
-            index_min, index_max = _find_indexes(self._obj, glb_LW_dn_name,
+            index_min, index_max = _find_indexes(self._ds, glb_LW_dn_name,
                                                  lw_min_dn_limit, lw_max_dn_limit, use_dask)
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_LW_dn_name, index=index_min, test_assessment='Bad',
                 test_meaning=f"Value less than BSRN {test.lower()} limit of {lw_min_dn_limit} W/m^2")
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_LW_dn_name, index=index_max, test_assessment='Bad',
                 test_meaning=f"Value greater than BSRN {test.lower()} limit of {lw_max_dn_limit} W/m^2")
 
         # Longwave upwelling min and max tests
         if glb_LW_up_name is not None:
-            index_min, index_max = _find_indexes(self._obj, glb_LW_up_name,
+            index_min, index_max = _find_indexes(self._ds, glb_LW_up_name,
                                                  lw_min_up_limit, lw_max_up_limit, use_dask)
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_LW_up_name, index=index_min, test_assessment='Bad',
                 test_meaning=f"Value less than BSRN {test.lower()} limit of {lw_min_up_limit} W/m^2")
 
-            self._obj.qcfilter.add_test(
+            self._ds.qcfilter.add_test(
                 glb_LW_up_name, index=index_max, test_assessment='Bad',
                 test_meaning=f"Value greater than BSRN {test.lower()} limit of {lw_max_up_limit} W/m^2")
 
@@ -404,8 +404,8 @@ class QCTests:
         --------
             .. code-block:: python
 
-                ds_object = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_BRS, cleanup_qc=True)
-                ds_object.qcfilter.bsrn_comparison_tests(
+                ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_BRS, cleanup_qc=True)
+                ds.qcfilter.bsrn_comparison_tests(
                     gbl_SW_dn_name='down_short_hemisp',
                     glb_diffuse_SW_dn_name='down_short_diffuse_hemisp',
                     direct_normal_SW_dn_name='short_direct_normal',
@@ -422,7 +422,7 @@ class QCTests:
                         'LW up to air temp', 'LW down to LW up']
 
         solar_constant = 1360.8
-        sza, Sa = _calculate_solar_parameters(self._obj, lat_name, lon_name, solar_constant)
+        sza, Sa = _calculate_solar_parameters(self._ds, lat_name, lon_name, solar_constant)
 
         # Ratio of Global over Sum SW
         if test_options[0] in test:
@@ -432,11 +432,11 @@ class QCTests:
 
             with warnings.catch_warnings():
                 warnings.filterwarnings('ignore', category=RuntimeWarning)
-                if use_dask and isinstance(self._obj[glb_diffuse_SW_dn_name].data, da.Array):
-                    sum_sw_down = (self._obj[glb_diffuse_SW_dn_name].data +
-                                   self._obj[direct_normal_SW_dn_name].data * np.cos(np.radians(sza)))
+                if use_dask and isinstance(self._ds[glb_diffuse_SW_dn_name].data, da.Array):
+                    sum_sw_down = (self._ds[glb_diffuse_SW_dn_name].data +
+                                   self._ds[direct_normal_SW_dn_name].data * np.cos(np.radians(sza)))
                     sum_sw_down[sum_sw_down < 50] = np.nan
-                    ratio = self._obj[gbl_SW_dn_name].data / sum_sw_down
+                    ratio = self._ds[gbl_SW_dn_name].data / sum_sw_down
                     index_a = sza < 75
                     index_1 = da.where((ratio > 1.08) & index_a, True, False)
                     index_2 = da.where((ratio < 0.92) & index_a, True, False)
@@ -445,10 +445,10 @@ class QCTests:
                     index_4 = da.where((ratio < 0.85) & index_b, True, False)
                     index = (index_1 | index_2 | index_3 | index_4).compute()
                 else:
-                    sum_sw_down = (self._obj[glb_diffuse_SW_dn_name].values +
-                                   self._obj[direct_normal_SW_dn_name].values * np.cos(np.radians(sza)))
+                    sum_sw_down = (self._ds[glb_diffuse_SW_dn_name].values +
+                                   self._ds[direct_normal_SW_dn_name].values * np.cos(np.radians(sza)))
                     sum_sw_down[sum_sw_down < 50] = np.nan
-                    ratio = self._obj[gbl_SW_dn_name].values / sum_sw_down
+                    ratio = self._ds[gbl_SW_dn_name].values / sum_sw_down
                     index_a = sza < 75
                     index_1 = (ratio > 1.08) & index_a
                     index_2 = (ratio < 0.92) & index_a
@@ -458,12 +458,12 @@ class QCTests:
                     index = index_1 | index_2 | index_3 | index_4
 
             test_meaning = "Ratio of Global over Sum shortwave larger than expected"
-            self._obj.qcfilter.add_test(gbl_SW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
-            self._obj.qcfilter.add_test(glb_diffuse_SW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
-            self._obj.qcfilter.add_test(direct_normal_SW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(gbl_SW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_diffuse_SW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(direct_normal_SW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
 
         # Diffuse Ratio
         if test_options[1] in test:
@@ -473,17 +473,17 @@ class QCTests:
 
             with warnings.catch_warnings():
                 warnings.filterwarnings('ignore', category=RuntimeWarning)
-                if use_dask and isinstance(self._obj[glb_diffuse_SW_dn_name].data, da.Array):
-                    ratio = self._obj[glb_diffuse_SW_dn_name].data / self._obj[gbl_SW_dn_name].data
-                    ratio[self._obj[gbl_SW_dn_name].data < 50] = np.nan
+                if use_dask and isinstance(self._ds[glb_diffuse_SW_dn_name].data, da.Array):
+                    ratio = self._ds[glb_diffuse_SW_dn_name].data / self._ds[gbl_SW_dn_name].data
+                    ratio[self._ds[gbl_SW_dn_name].data < 50] = np.nan
                     index_a = sza < 75
                     index_1 = da.where((ratio >= 1.05) & index_a, True, False)
                     index_b = (sza >= 75) & (sza < 93)
                     index_2 = da.where((ratio >= 1.10) & index_b, True, False)
                     index = (index_1 | index_2).compute()
                 else:
-                    ratio = self._obj[glb_diffuse_SW_dn_name].values / self._obj[gbl_SW_dn_name].values
-                    ratio[self._obj[gbl_SW_dn_name].values < 50] = np.nan
+                    ratio = self._ds[glb_diffuse_SW_dn_name].values / self._ds[gbl_SW_dn_name].values
+                    ratio[self._ds[gbl_SW_dn_name].values < 50] = np.nan
                     index_a = sza < 75
                     index_1 = (ratio >= 1.05) & index_a
                     index_b = (sza >= 75) & (sza < 93)
@@ -491,10 +491,10 @@ class QCTests:
                     index = index_1 | index_2
 
             test_meaning = "Ratio of Diffuse Shortwave over Global Shortwave larger than expected"
-            self._obj.qcfilter.add_test(gbl_SW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
-            self._obj.qcfilter.add_test(glb_diffuse_SW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(gbl_SW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_diffuse_SW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
 
         # Shortwave up comparison
         if test_options[2] in test:
@@ -504,25 +504,25 @@ class QCTests:
 
             with warnings.catch_warnings():
                 warnings.filterwarnings('ignore', category=RuntimeWarning)
-                if use_dask and isinstance(self._obj[glb_diffuse_SW_dn_name].data, da.Array):
-                    sum_sw_down = (self._obj[glb_diffuse_SW_dn_name].data +
-                                   self._obj[direct_normal_SW_dn_name].data * np.cos(np.radians(sza)))
+                if use_dask and isinstance(self._ds[glb_diffuse_SW_dn_name].data, da.Array):
+                    sum_sw_down = (self._ds[glb_diffuse_SW_dn_name].data +
+                                   self._ds[direct_normal_SW_dn_name].data * np.cos(np.radians(sza)))
 
                     sum_sw_down[sum_sw_down < 50] = np.nan
-                    index = da.where(self._obj[glb_SW_up_name].data > sum_sw_down, True, False).compute()
+                    index = da.where(self._ds[glb_SW_up_name].data > sum_sw_down, True, False).compute()
                 else:
-                    sum_sw_down = (self._obj[glb_diffuse_SW_dn_name].values +
-                                   self._obj[direct_normal_SW_dn_name].values * np.cos(np.radians(sza)))
+                    sum_sw_down = (self._ds[glb_diffuse_SW_dn_name].values +
+                                   self._ds[direct_normal_SW_dn_name].values * np.cos(np.radians(sza)))
                     sum_sw_down[sum_sw_down < 50] = np.nan
-                    index = self._obj[glb_SW_up_name].values > sum_sw_down
+                    index = self._ds[glb_SW_up_name].values > sum_sw_down
 
             test_meaning = "Ratio of Shortwave Upwelling greater than Shortwave Sum"
-            self._obj.qcfilter.add_test(glb_SW_up_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
-            self._obj.qcfilter.add_test(glb_diffuse_SW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
-            self._obj.qcfilter.add_test(direct_normal_SW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_SW_up_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_diffuse_SW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(direct_normal_SW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
 
         # Longwave down to air temperature comparison
         if test_options[3] in test:
@@ -530,23 +530,23 @@ class QCTests:
                 raise ValueError('Must set keywords glb_LW_dn_name, air_temp_name '
                                  f' for {test_options[3]} test.')
 
-            air_temp = convert_units(self._obj[air_temp_name].values,
-                                     self._obj[air_temp_name].attrs['units'], 'degK')
-            if use_dask and isinstance(self._obj[glb_LW_dn_name].data, da.Array):
+            air_temp = convert_units(self._ds[air_temp_name].values,
+                                     self._ds[air_temp_name].attrs['units'], 'degK')
+            if use_dask and isinstance(self._ds[glb_LW_dn_name].data, da.Array):
                 air_temp = da.array(air_temp)
                 conversion = da.array(Stefan_Boltzmann * air_temp**4)
-                index_1 = (0.4 * conversion) > self._obj[glb_LW_dn_name].data
-                index_2 = (conversion + 25.) < self._obj[glb_LW_dn_name].data
+                index_1 = (0.4 * conversion) > self._ds[glb_LW_dn_name].data
+                index_2 = (conversion + 25.) < self._ds[glb_LW_dn_name].data
                 index = (index_1 | index_2).compute()
             else:
                 conversion = Stefan_Boltzmann * air_temp**4
-                index_1 = (0.4 * conversion) > self._obj[glb_LW_dn_name].values
-                index_2 = (conversion + 25.) < self._obj[glb_LW_dn_name].values
+                index_1 = (0.4 * conversion) > self._ds[glb_LW_dn_name].values
+                index_2 = (conversion + 25.) < self._ds[glb_LW_dn_name].values
                 index = index_1 | index_2
 
             test_meaning = "Longwave downwelling comparison to air temperature out side of expected range"
-            self._obj.qcfilter.add_test(glb_LW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_LW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
 
         # Longwave up to air temperature comparison
         if test_options[4] in test:
@@ -554,21 +554,21 @@ class QCTests:
                 raise ValueError('Must set keywords glb_LW_up_name, air_temp_name '
                                  f'for {test_options[3]} test.')
 
-            air_temp = convert_units(self._obj[air_temp_name].values,
-                                     self._obj[air_temp_name].attrs['units'], 'degK')
-            if use_dask and isinstance(self._obj[glb_LW_up_name].data, da.Array):
+            air_temp = convert_units(self._ds[air_temp_name].values,
+                                     self._ds[air_temp_name].attrs['units'], 'degK')
+            if use_dask and isinstance(self._ds[glb_LW_up_name].data, da.Array):
                 air_temp = da.array(air_temp)
-                index_1 = (Stefan_Boltzmann * (air_temp - 15)**4) > self._obj[glb_LW_up_name].data
-                index_2 = (Stefan_Boltzmann * (air_temp + 25)**4) < self._obj[glb_LW_up_name].data
+                index_1 = (Stefan_Boltzmann * (air_temp - 15)**4) > self._ds[glb_LW_up_name].data
+                index_2 = (Stefan_Boltzmann * (air_temp + 25)**4) < self._ds[glb_LW_up_name].data
                 index = (index_1 | index_2).compute()
             else:
-                index_1 = (Stefan_Boltzmann * (air_temp - 15)**4) > self._obj[glb_LW_up_name].values
-                index_2 = (Stefan_Boltzmann * (air_temp + 25)**4) < self._obj[glb_LW_up_name].values
+                index_1 = (Stefan_Boltzmann * (air_temp - 15)**4) > self._ds[glb_LW_up_name].values
+                index_2 = (Stefan_Boltzmann * (air_temp + 25)**4) < self._ds[glb_LW_up_name].values
                 index = index_1 | index_2
 
             test_meaning = "Longwave upwelling comparison to air temperature out side of expected range"
-            self._obj.qcfilter.add_test(glb_LW_up_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_LW_up_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
 
         # Lonwave down to longwave up comparison
         if test_options[5] in test:
@@ -576,19 +576,19 @@ class QCTests:
                 raise ValueError('Must set keywords glb_LW_dn_name, glb_LW_up_name '
                                  f'for {test_options[3]} test.')
 
-            if use_dask and isinstance(self._obj[glb_LW_dn_name].data, da.Array):
-                index_1 = da.where(self._obj[glb_LW_dn_name].data >
-                                   (self._obj[glb_LW_up_name].data + LWdn_lt_LWup_component), True, False)
-                index_2 = da.where(self._obj[glb_LW_dn_name].data <
-                                   (self._obj[glb_LW_up_name].data - LWdn_gt_LWup_component), True, False)
+            if use_dask and isinstance(self._ds[glb_LW_dn_name].data, da.Array):
+                index_1 = da.where(self._ds[glb_LW_dn_name].data >
+                                   (self._ds[glb_LW_up_name].data + LWdn_lt_LWup_component), True, False)
+                index_2 = da.where(self._ds[glb_LW_dn_name].data <
+                                   (self._ds[glb_LW_up_name].data - LWdn_gt_LWup_component), True, False)
                 index = (index_1 | index_2).compute()
             else:
-                index_1 = self._obj[glb_LW_dn_name].values > (self._obj[glb_LW_up_name].values + LWdn_lt_LWup_component)
-                index_2 = self._obj[glb_LW_dn_name].values < (self._obj[glb_LW_up_name].values - LWdn_gt_LWup_component)
+                index_1 = self._ds[glb_LW_dn_name].values > (self._ds[glb_LW_up_name].values + LWdn_lt_LWup_component)
+                index_2 = self._ds[glb_LW_dn_name].values < (self._ds[glb_LW_up_name].values - LWdn_gt_LWup_component)
                 index = index_1 | index_2
 
             test_meaning = "Lonwave downwelling compared to longwave upwelling outside of expected range"
-            self._obj.qcfilter.add_test(glb_LW_dn_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
-            self._obj.qcfilter.add_test(glb_LW_up_name, index=index, test_assessment=test_assessment,
-                                        test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_LW_dn_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
+            self._ds.qcfilter.add_test(glb_LW_up_name, index=index, test_assessment=test_assessment,
+                                       test_meaning=test_meaning)
