@@ -9,6 +9,7 @@ import os
 DATA_PATH = os.path.join(os.path.dirname(__file__), 'data')
 
 EXAMPLE_MET1 = os.path.join(DATA_PATH, 'sgpmetE13.b1.20190101.000000.cdf')
+EXAMPLE_MET_SAIL = os.path.join(DATA_PATH, 'gucmetM1.b1.20230301.000000.cdf')
 EXAMPLE_MET_CSV = os.path.join(DATA_PATH, 'sgpmetE13.*csv')
 EXAMPLE_METE40 = os.path.join(DATA_PATH, 'sgpmetE40.b1.20190508.000000.cdf')
 EXAMPLE_CEIL1 = os.path.join(DATA_PATH, 'sgpceilC1.b1.20190101.000000.nc')
@@ -28,8 +29,6 @@ EXAMPLE_NAV = os.path.join(DATA_PATH, 'marnavM1.a1.20180201.000000.nc')
 EXAMPLE_AOSMET = os.path.join(DATA_PATH, 'maraosmetM1.a1.20180201.000000.nc')
 EXAMPLE_DLPPI = os.path.join(DATA_PATH, 'sgpdlppiC1.b1.20191015.120023.cdf')
 EXAMPLE_DLPPI_MULTI = os.path.join(DATA_PATH, 'sgpdlppiC1.b1.20191015.*.cdf')
-EXAMPLE_EBBR1 = os.path.join(DATA_PATH, 'sgp30ebbrE32.b1.20191125.000000.nc')
-EXAMPLE_EBBR2 = os.path.join(DATA_PATH, 'sgp30ebbrE32.b1.20191130.000000.nc')
 EXAMPLE_BRS = os.path.join(DATA_PATH, 'sgpbrsC1.b1.20190705.000000.cdf')
 EXAMPLE_AERI = os.path.join(DATA_PATH, 'sgpaerich1C1.b1.20190501.000342.nc')
 EXAMPLE_IRTSST = os.path.join(DATA_PATH, 'marirtsstM1.b1.20190320.000000.nc')
@@ -63,3 +62,8 @@ EXAMPLE_NEON = os.path.join(DATA_PATH, 'NEON.D18.BARR.DP1.00002.001.000.010.001.
 EXAMPLE_NEON_VARIABLE = os.path.join(DATA_PATH, 'NEON.D18.BARR.DP1.00002.001.variables.20221201T110553Z.csv')
 EXAMPLE_NEON_POSITION = os.path.join(DATA_PATH, 'NEON.D18.BARR.DP1.00002.001.sensor_positions.20221107T205629Z.csv')
 EXAMPLE_DOD = os.path.join(DATA_PATH, 'vdis.b1')
+EXAMPLE_EBBR1 = os.path.join(DATA_PATH, 'sgp30ebbrE32.b1.20191125.000000.nc')
+EXAMPLE_EBBR2 = os.path.join(DATA_PATH, 'sgp30ebbrE32.b1.20191130.000000.nc')
+EXAMPLE_EBBR3 = os.path.join(DATA_PATH, 'sgp30ebbrE13.b1.20190601.000000.nc')
+EXAMPLE_ECOR = os.path.join(DATA_PATH, 'sgp30ecorE14.b1.20190601.000000.cdf')
+EXAMPLE_SEBS = os.path.join(DATA_PATH, 'sgpsebsE14.b1.20190601.000000.cdf')
