@@ -86,31 +86,31 @@ def test_keep_variables():
     ]
     assert drop_variables.sort() == expected_drop_variables.sort()
 
-    ds_object = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_MET1, keep_variables='temp_mean')
-    assert list(ds_object.data_vars) == ['temp_mean']
-    del ds_object
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_MET1, keep_variables='temp_mean')
+    assert list(ds.data_vars) == ['temp_mean']
+    del ds
 
     var_names = ['temp_mean', 'qc_temp_mean']
-    ds_object = act.io.armfiles.read_netcdf(
+    ds = act.io.armfiles.read_netcdf(
         act.tests.EXAMPLE_MET1, keep_variables=var_names, drop_variables='nonsense'
     )
-    assert list(ds_object.data_vars).sort() == var_names.sort()
-    del ds_object
+    assert list(ds.data_vars).sort() == var_names.sort()
+    del ds
 
     var_names = ['temp_mean', 'qc_temp_mean', 'alt', 'lat', 'lon']
-    ds_object = act.io.armfiles.read_netcdf(
+    ds = act.io.armfiles.read_netcdf(
         act.tests.EXAMPLE_MET_WILDCARD, keep_variables=var_names, drop_variables=['lon']
     )
     var_names = list(set(var_names) - {'lon'})
-    assert list(ds_object.data_vars).sort() == var_names.sort()
-    del ds_object
+    assert list(ds.data_vars).sort() == var_names.sort()
+    del ds
 
     filenames = Path(act.tests.EXAMPLE_MET_WILDCARD).parent
     filenames = list(filenames.glob(Path(act.tests.EXAMPLE_MET_WILDCARD).name))
     var_names = ['temp_mean', 'qc_temp_mean', 'alt', 'lat', 'lon']
-    ds_object = act.io.armfiles.read_netcdf(filenames, keep_variables=var_names)
-    assert list(ds_object.data_vars).sort() == var_names.sort()
-    del ds_object
+    ds = act.io.armfiles.read_netcdf(filenames, keep_variables=var_names)
+    assert list(ds.data_vars).sort() == var_names.sort()
+    del ds
 
 
 def test_io_mfdataset():
@@ -181,38 +181,38 @@ def test_io_csv():
     anl_ds.close()
 
     files = glob.glob(act.tests.EXAMPLE_MET_CSV)
-    obj = act.io.csvfiles.read_csv(files[0])
-    assert 'date_time' in obj
-    assert '_datastream' in obj.attrs
+    ds = act.io.csvfiles.read_csv(files[0])
+    assert 'date_time' in ds
+    assert '_datastream' in ds.attrs
 
 
 def test_io_dod():
     dims = {'time': 1440, 'drop_diameter': 50}
 
     try:
-        obj = act.io.armfiles.create_obj_from_arm_dod(
+        ds = act.io.armfiles.create_ds_from_arm_dod(
             'vdis.b1', dims, version='1.2', scalar_fill_dim='time'
         )
-        assert 'moment1' in obj
-        assert len(obj['base_time'].values) == 1440
-        assert len(obj['drop_diameter'].values) == 50
+        assert 'moment1' in ds
+        assert len(ds['base_time'].values) == 1440
+        assert len(ds['drop_diameter'].values) == 50
         with np.testing.assert_warns(UserWarning):
-            obj2 = act.io.armfiles.create_obj_from_arm_dod('vdis.b1', dims, scalar_fill_dim='time')
-        assert 'moment1' in obj2
-        assert len(obj2['base_time'].values) == 1440
-        assert len(obj2['drop_diameter'].values) == 50
+            ds2 = act.io.armfiles.create_ds_from_arm_dod('vdis.b1', dims, scalar_fill_dim='time')
+        assert 'moment1' in ds2
+        assert len(ds2['base_time'].values) == 1440
+        assert len(ds2['drop_diameter'].values) == 50
         with np.testing.assert_raises(ValueError):
-            obj = act.io.armfiles.create_obj_from_arm_dod('vdis.b1', {}, version='1.2')
-        obj = act.io.armfiles.create_obj_from_arm_dod(
+            ds = act.io.armfiles.create_ds_from_arm_dod('vdis.b1', {}, version='1.2')
+        ds = act.io.armfiles.create_ds_from_arm_dod(
             sample_files.EXAMPLE_DOD, dims, version=1.2, scalar_fill_dim='time',
             local_file=True)
-        assert 'moment1' in obj
-        assert len(obj['base_time'].values) == 1440
-        assert len(obj['drop_diameter'].values) == 50
+        assert 'moment1' in ds
+        assert len(ds['base_time'].values) == 1440
+        assert len(ds['drop_diameter'].values) == 50
     except Exception:
         return
-    obj.close()
-    obj2.close()
+    ds.close()
+    ds2.close()
 
 
 def test_io_write():
@@ -269,11 +269,11 @@ def test_io_write():
 
     sonde_ds.close()
 
-    obj = act.io.armfiles.read_netcdf(sample_files.EXAMPLE_CEIL1)
+    ds = act.io.armfiles.read_netcdf(sample_files.EXAMPLE_CEIL1)
     with tempfile.TemporaryDirectory() as tmpdirname:
         cf_convention = 'CF-1.8'
         write_file = Path(tmpdirname, Path(sample_files.EXAMPLE_CEIL1).name)
-        obj.write.write_netcdf(
+        ds.write.write_netcdf(
             path=write_file,
             make_copy=False,
             join_char='_',
@@ -281,51 +281,51 @@ def test_io_write():
             cf_convention=cf_convention,
         )
 
-        obj_read = act.io.armfiles.read_netcdf(str(write_file))
+        ds_read = act.io.armfiles.read_netcdf(str(write_file))
 
-        assert cf_convention in obj_read.attrs['Conventions'].split()
-        assert obj_read.attrs['FeatureType'] == 'timeSeriesProfile'
-        assert len(obj_read.dims) > 1
+        assert cf_convention in ds_read.attrs['Conventions'].split()
+        assert ds_read.attrs['FeatureType'] == 'timeSeriesProfile'
+        assert len(ds_read.dims) > 1
 
-        obj_read.close()
-        del obj_read
+        ds_read.close()
+        del ds_read
 
 
 def test_clean_cf_qc():
     with tempfile.TemporaryDirectory() as tmpdirname:
-        obj = act.io.armfiles.read_netcdf(sample_files.EXAMPLE_MET1, cleanup_qc=True)
-        obj.load()
+        ds = act.io.armfiles.read_netcdf(sample_files.EXAMPLE_MET1, cleanup_qc=True)
+        ds.load()
         var_name = 'temp_mean'
         qc_var_name = 'qc_' + var_name
-        obj.qcfilter.remove_test(var_name, test_number=4)
-        obj.qcfilter.remove_test(var_name, test_number=3)
-        obj.qcfilter.remove_test(var_name, test_number=2)
-        obj[qc_var_name].attrs['flag_masks'] = obj[qc_var_name].attrs['flag_masks'][0]
-        flag_meanings = obj[qc_var_name].attrs['flag_meanings'][0]
-        obj[qc_var_name].attrs['flag_meanings'] = flag_meanings.replace(' ', '__')
-        flag_meanings = obj[qc_var_name].attrs['flag_assessments'][0]
-        obj[qc_var_name].attrs['flag_assessments'] = flag_meanings.replace(' ', '__')
+        ds.qcfilter.remove_test(var_name, test_number=4)
+        ds.qcfilter.remove_test(var_name, test_number=3)
+        ds.qcfilter.remove_test(var_name, test_number=2)
+        ds[qc_var_name].attrs['flag_masks'] = ds[qc_var_name].attrs['flag_masks'][0]
+        flag_meanings = ds[qc_var_name].attrs['flag_meanings'][0]
+        ds[qc_var_name].attrs['flag_meanings'] = flag_meanings.replace(' ', '__')
+        flag_meanings = ds[qc_var_name].attrs['flag_assessments'][0]
+        ds[qc_var_name].attrs['flag_assessments'] = flag_meanings.replace(' ', '__')
 
         write_file = str(Path(tmpdirname, Path(sample_files.EXAMPLE_MET1).name))
-        obj.write.write_netcdf(path=write_file, cf_compliant=True)
-        obj.close()
-        del obj
+        ds.write.write_netcdf(path=write_file, cf_compliant=True)
+        ds.close()
+        del ds
 
-        read_obj = act.io.armfiles.read_netcdf(write_file, cleanup_qc=True)
-        read_obj.load()
+        read_ds = act.io.armfiles.read_netcdf(write_file, cleanup_qc=True)
+        read_ds.load()
 
-        assert type(read_obj[qc_var_name].attrs['flag_masks']).__module__ == 'numpy'
-        assert read_obj[qc_var_name].attrs['flag_masks'].size == 1
-        assert read_obj[qc_var_name].attrs['flag_masks'][0] == 1
-        assert isinstance(read_obj[qc_var_name].attrs['flag_meanings'], list)
-        assert len(read_obj[qc_var_name].attrs['flag_meanings']) == 1
-        assert isinstance(read_obj[qc_var_name].attrs['flag_assessments'], list)
-        assert len(read_obj[qc_var_name].attrs['flag_assessments']) == 1
-        assert read_obj[qc_var_name].attrs['flag_assessments'] == ['Bad']
-        assert read_obj[qc_var_name].attrs['flag_meanings'] == ['Value is equal to missing_value.']
+        assert type(read_ds[qc_var_name].attrs['flag_masks']).__module__ == 'numpy'
+        assert read_ds[qc_var_name].attrs['flag_masks'].size == 1
+        assert read_ds[qc_var_name].attrs['flag_masks'][0] == 1
+        assert isinstance(read_ds[qc_var_name].attrs['flag_meanings'], list)
+        assert len(read_ds[qc_var_name].attrs['flag_meanings']) == 1
+        assert isinstance(read_ds[qc_var_name].attrs['flag_assessments'], list)
+        assert len(read_ds[qc_var_name].attrs['flag_assessments']) == 1
+        assert read_ds[qc_var_name].attrs['flag_assessments'] == ['Bad']
+        assert read_ds[qc_var_name].attrs['flag_meanings'] == ['Value is equal to missing_value.']
 
-        read_obj.close()
-        del read_obj
+        read_ds.close()
+        del read_ds
 
 
 def test_io_mpldataset():
@@ -464,23 +464,23 @@ def test_read_gml():
 
 
 def test_read_psl_wind_profiler():
-    test_obj_low, test_obj_hi = act.io.noaapsl.read_psl_wind_profiler(
+    test_ds_low, test_ds_hi = act.io.noaapsl.read_psl_wind_profiler(
         act.tests.EXAMPLE_NOAA_PSL, transpose=False
     )
     # test dimensions
-    assert 'time' and 'HT' in test_obj_low.dims.keys()
-    assert 'time' and 'HT' in test_obj_hi.dims.keys()
-    assert test_obj_low.dims['time'] == 4
-    assert test_obj_hi.dims['time'] == 4
-    assert test_obj_low.dims['HT'] == 49
-    assert test_obj_hi.dims['HT'] == 50
+    assert 'time' and 'HT' in test_ds_low.dims.keys()
+    assert 'time' and 'HT' in test_ds_hi.dims.keys()
+    assert test_ds_low.dims['time'] == 4
+    assert test_ds_hi.dims['time'] == 4
+    assert test_ds_low.dims['HT'] == 49
+    assert test_ds_hi.dims['HT'] == 50
 
     # test coordinates
     assert (
-        test_obj_low.coords['HT'][0:5] == np.array([0.151, 0.254, 0.356, 0.458, 0.561])
+        test_ds_low.coords['HT'][0:5] == np.array([0.151, 0.254, 0.356, 0.458, 0.561])
     ).all()
     assert (
-        test_obj_low.coords['time'][0:2]
+        test_ds_low.coords['time'][0:2]
         == np.array(
             ['2021-05-05T15:00:01.000000000', '2021-05-05T15:15:49.000000000'],
             dtype='datetime64[ns]',
@@ -488,59 +488,59 @@ def test_read_psl_wind_profiler():
     ).all()
 
     # test attributes
-    assert test_obj_low.attrs['site_identifier'] == 'CTD'
-    assert test_obj_low.attrs['data_type'] == 'WINDS'
-    assert test_obj_low.attrs['revision_number'] == '5.1'
-    assert test_obj_low.attrs['latitude'] == 34.66
-    assert test_obj_low.attrs['longitude'] == -87.35
-    assert test_obj_low.attrs['elevation'] == 187.0
-    assert (test_obj_low.attrs['beam_azimuth'] == np.array(
+    assert test_ds_low.attrs['site_identifier'] == 'CTD'
+    assert test_ds_low.attrs['data_type'] == 'WINDS'
+    assert test_ds_low.attrs['revision_number'] == '5.1'
+    assert test_ds_low.attrs['latitude'] == 34.66
+    assert test_ds_low.attrs['longitude'] == -87.35
+    assert test_ds_low.attrs['elevation'] == 187.0
+    assert (test_ds_low.attrs['beam_azimuth'] == np.array(
         [38.0, 38.0, 308.0], dtype='float32')).all()
-    assert (test_obj_low.attrs['beam_elevation'] == np.array(
+    assert (test_ds_low.attrs['beam_elevation'] == np.array(
         [90.0, 74.7, 74.7], dtype='float32')).all()
-    assert test_obj_low.attrs['consensus_average_time'] == 24
-    assert test_obj_low.attrs['oblique-beam_vertical_correction'] == 0
-    assert test_obj_low.attrs['number_of_beams'] == 3
-    assert test_obj_low.attrs['number_of_range_gates'] == 49
-    assert test_obj_low.attrs['number_of_gates_oblique'] == 49
-    assert test_obj_low.attrs['number_of_gates_vertical'] == 49
-    assert test_obj_low.attrs['number_spectral_averages_oblique'] == 50
-    assert test_obj_low.attrs['number_spectral_averages_vertical'] == 50
-    assert test_obj_low.attrs['pulse_width_oblique'] == 708
-    assert test_obj_low.attrs['pulse_width_vertical'] == 708
-    assert test_obj_low.attrs['inner_pulse_period_oblique'] == 50
-    assert test_obj_low.attrs['inner_pulse_period_vertical'] == 50
-    assert test_obj_low.attrs['full_scale_doppler_value_oblique'] == 20.9
-    assert test_obj_low.attrs['full_scale_doppler_value_vertical'] == 20.9
-    assert test_obj_low.attrs['delay_to_first_gate_oblique'] == 4000
-    assert test_obj_low.attrs['delay_to_first_gate_vertical'] == 4000
-    assert test_obj_low.attrs['spacing_of_gates_oblique'] == 708
-    assert test_obj_low.attrs['spacing_of_gates_vertical'] == 708
+    assert test_ds_low.attrs['consensus_average_time'] == 24
+    assert test_ds_low.attrs['oblique-beam_vertical_correction'] == 0
+    assert test_ds_low.attrs['number_of_beams'] == 3
+    assert test_ds_low.attrs['number_of_range_gates'] == 49
+    assert test_ds_low.attrs['number_of_gates_oblique'] == 49
+    assert test_ds_low.attrs['number_of_gates_vertical'] == 49
+    assert test_ds_low.attrs['number_spectral_averages_oblique'] == 50
+    assert test_ds_low.attrs['number_spectral_averages_vertical'] == 50
+    assert test_ds_low.attrs['pulse_width_oblique'] == 708
+    assert test_ds_low.attrs['pulse_width_vertical'] == 708
+    assert test_ds_low.attrs['inner_pulse_period_oblique'] == 50
+    assert test_ds_low.attrs['inner_pulse_period_vertical'] == 50
+    assert test_ds_low.attrs['full_scale_doppler_value_oblique'] == 20.9
+    assert test_ds_low.attrs['full_scale_doppler_value_vertical'] == 20.9
+    assert test_ds_low.attrs['delay_to_first_gate_oblique'] == 4000
+    assert test_ds_low.attrs['delay_to_first_gate_vertical'] == 4000
+    assert test_ds_low.attrs['spacing_of_gates_oblique'] == 708
+    assert test_ds_low.attrs['spacing_of_gates_vertical'] == 708
 
     # test fields
-    assert test_obj_low['RAD1'].shape == (4, 49)
-    assert test_obj_hi['RAD1'].shape == (4, 50)
-    assert (test_obj_low['RAD1'][0, 0:5] == np.array(
+    assert test_ds_low['RAD1'].shape == (4, 49)
+    assert test_ds_hi['RAD1'].shape == (4, 50)
+    assert (test_ds_low['RAD1'][0, 0:5] == np.array(
         [0.2, 0.1, 0.1, 0.0, -0.1])).all()
-    assert (test_obj_hi['RAD1'][0, 0:5] == np.array(
+    assert (test_ds_hi['RAD1'][0, 0:5] == np.array(
         [0.1, 0.1, -0.1, 0.0, -0.2])).all()
 
-    assert test_obj_low['SPD'].shape == (4, 49)
-    assert test_obj_hi['SPD'].shape == (4, 50)
-    assert (test_obj_low['SPD'][0, 0:5] == np.array(
+    assert test_ds_low['SPD'].shape == (4, 49)
+    assert test_ds_hi['SPD'].shape == (4, 50)
+    assert (test_ds_low['SPD'][0, 0:5] == np.array(
         [2.5, 3.3, 4.3, 4.3, 4.8])).all()
-    assert (test_obj_hi['SPD'][0, 0:5] == np.array(
+    assert (test_ds_hi['SPD'][0, 0:5] == np.array(
         [3.7, 4.6, 6.3, 5.2, 6.8])).all()
 
     # test transpose
-    test_obj_low, test_obj_hi = act.io.noaapsl.read_psl_wind_profiler(
+    test_ds_low, test_ds_hi = act.io.noaapsl.read_psl_wind_profiler(
         act.tests.EXAMPLE_NOAA_PSL, transpose=True
     )
-    assert test_obj_low['RAD1'].shape == (49, 4)
-    assert test_obj_hi['RAD1'].shape == (50, 4)
-    assert test_obj_low['SPD'].shape == (49, 4)
-    assert test_obj_hi['SPD'].shape == (50, 4)
-    test_obj_low.close()
+    assert test_ds_low['RAD1'].shape == (49, 4)
+    assert test_ds_hi['RAD1'].shape == (50, 4)
+    assert test_ds_low['SPD'].shape == (49, 4)
+    assert test_ds_hi['SPD'].shape == (50, 4)
+    test_ds_low.close()
 
 
 def test_read_psl_wind_profiler_temperature():
@@ -553,16 +553,16 @@ def test_read_psl_wind_profiler_temperature():
 
 
 def test_read_psl_surface_met():
-    ds_object = read_psl_surface_met(sample_files.EXAMPLE_NOAA_PSL_SURFACEMET)
-    assert ds_object.time.size == 2
-    assert np.isclose(np.sum(ds_object['Pressure'].values), 1446.9)
-    assert np.isclose(ds_object['lat'].values, 38.972425)
-    assert ds_object['lat'].attrs['units'] == 'degree_N'
-    assert ds_object['Upward_Longwave_Irradiance'].attrs['long_name'] == 'Upward Longwave Irradiance'
-    assert ds_object['Upward_Longwave_Irradiance'].dtype.str == '<f4'
+    ds = read_psl_surface_met(sample_files.EXAMPLE_NOAA_PSL_SURFACEMET)
+    assert ds.time.size == 2
+    assert np.isclose(np.sum(ds['Pressure'].values), 1446.9)
+    assert np.isclose(ds['lat'].values, 38.972425)
+    assert ds['lat'].attrs['units'] == 'degree_N'
+    assert ds['Upward_Longwave_Irradiance'].attrs['long_name'] == 'Upward Longwave Irradiance'
+    assert ds['Upward_Longwave_Irradiance'].dtype.str == '<f4'
 
     with pytest.raises(Exception):
-        ds_object = read_psl_surface_met('aaa22001.00m')
+        ds = read_psl_surface_met('aaa22001.00m')
 
 
 def test_read_psl_parsivel():
@@ -570,14 +570,14 @@ def test_read_psl_parsivel():
            'https://downloads.psl.noaa.gov/psd2/data/realtime/DisdrometerParsivel/Stats/ctd/2022/002/ctd2200201_stats.txt',
            'https://downloads.psl.noaa.gov/psd2/data/realtime/DisdrometerParsivel/Stats/ctd/2022/002/ctd2200202_stats.txt']
 
-    obj = act.io.noaapsl.read_psl_parsivel(url)
-    assert 'number_density_drops' in obj
-    assert np.max(obj['number_density_drops'].values) == 355
-    assert obj['number_density_drops'].values[10, 10] == 201
+    ds = act.io.noaapsl.read_psl_parsivel(url)
+    assert 'number_density_drops' in ds
+    assert np.max(ds['number_density_drops'].values) == 355
+    assert ds['number_density_drops'].values[10, 10] == 201
 
-    obj = act.io.noaapsl.read_psl_parsivel(
+    ds = act.io.noaapsl.read_psl_parsivel(
         'https://downloads.psl.noaa.gov/psd2/data/realtime/DisdrometerParsivel/Stats/ctd/2022/002/ctd2200201_stats.txt')
-    assert 'number_density_drops' in obj
+    assert 'number_density_drops' in ds
 
 
 def test_read_psl_fmcw_moment():
@@ -585,12 +585,12 @@ def test_read_psl_fmcw_moment():
         site='kps', instrument='Radar FMCW Moment',
         startdate='20220815', hour='06'
     )
-    obj = act.io.noaapsl.read_psl_radar_fmcw_moment([result[-1]])
-    assert 'range' in obj
+    ds = act.io.noaapsl.read_psl_radar_fmcw_moment([result[-1]])
+    assert 'range' in ds
     np.testing.assert_almost_equal(
-        obj['reflectivity_uncalibrated'].mean(), 2.37, decimal=2)
-    assert obj['range'].max() == 10040.
-    assert len(obj['time'].values) == 115
+        ds['reflectivity_uncalibrated'].mean(), 2.37, decimal=2)
+    assert ds['range'].max() == 10040.
+    assert len(ds['time'].values) == 115
 
 
 def test_read_psl_sband_moment():
@@ -598,12 +598,12 @@ def test_read_psl_sband_moment():
         site='ctd', instrument='Radar S-band Moment',
         startdate='20211225', hour='06'
     )
-    obj = act.io.noaapsl.read_psl_radar_sband_moment([result[-1]])
-    assert 'range' in obj
+    ds = act.io.noaapsl.read_psl_radar_sband_moment([result[-1]])
+    assert 'range' in ds
     np.testing.assert_almost_equal(
-        obj['reflectivity_uncalibrated'].mean(), 1.00, decimal=2)
-    assert obj['range'].max() == 9997.
-    assert len(obj['time'].values) == 37
+        ds['reflectivity_uncalibrated'].mean(), 1.00, decimal=2)
+    assert ds['range'].max() == 9997.
+    assert len(ds['time'].values) == 37
 
 
 @pytest.mark.skipif(not act.io.icartt._ICARTT_AVAILABLE,
@@ -794,10 +794,10 @@ def test_read_netcdf_tarfiles():
         met_files = Path(act.tests.EXAMPLE_MET_WILDCARD)
         met_files = list(Path(met_files.parent).glob(met_files.name))
         filename = act.utils.io_utils.pack_tar(met_files, write_directory=tmpdirname)
-        ds_object = act.io.armfiles.read_netcdf(filename)
-        ds_object.clean.cleanup()
+        ds = act.io.armfiles.read_netcdf(filename)
+        ds.clean.cleanup()
 
-        assert 'temp_mean' in ds_object.data_vars
+        assert 'temp_mean' in ds.data_vars
 
 
 def test_read_netcdf_gztarfiles():
@@ -806,29 +806,29 @@ def test_read_netcdf_gztarfiles():
         met_files = list(Path(met_files.parent).glob(met_files.name))
         filename = act.utils.io_utils.pack_tar(met_files, write_directory=tmpdirname)
         filename = act.utils.io_utils.pack_gzip(filename, write_directory=tmpdirname, remove=True)
-        ds_object = act.io.armfiles.read_netcdf(filename)
-        ds_object.clean.cleanup()
+        ds = act.io.armfiles.read_netcdf(filename)
+        ds.clean.cleanup()
 
-        assert 'temp_mean' in ds_object.data_vars
+        assert 'temp_mean' in ds.data_vars
 
     with tempfile.TemporaryDirectory() as tmpdirname:
         met_files = sample_files.EXAMPLE_MET1
         filename = act.utils.io_utils.pack_gzip(met_files, write_directory=tmpdirname, remove=False)
-        ds_object = act.io.armfiles.read_netcdf(filename)
-        ds_object.clean.cleanup()
+        ds = act.io.armfiles.read_netcdf(filename)
+        ds.clean.cleanup()
 
-        assert 'temp_mean' in ds_object.data_vars
+        assert 'temp_mean' in ds.data_vars
 
 
 def test_read_mmcr():
     results = glob.glob(act.tests.EXAMPLE_MMCR)
-    obj = act.io.armfiles.read_mmcr(results)
-    assert 'MeanDopplerVelocity_PR' in obj
-    assert 'SpectralWidth_BL' in obj
+    ds = act.io.armfiles.read_mmcr(results)
+    assert 'MeanDopplerVelocity_PR' in ds
+    assert 'SpectralWidth_BL' in ds
     np.testing.assert_almost_equal(
-        obj['Reflectivity_GE'].mean(), -34.62, decimal=2)
+        ds['Reflectivity_GE'].mean(), -34.62, decimal=2)
     np.testing.assert_almost_equal(
-        obj['MeanDopplerVelocity_Receiver1'].max(), 9.98, decimal=2)
+        ds['MeanDopplerVelocity_Receiver1'].max(), 9.98, decimal=2)
 
 
 def test_read_neon():
@@ -836,14 +836,14 @@ def test_read_neon():
     variable_file = glob.glob(act.tests.EXAMPLE_NEON_VARIABLE)
     position_file = glob.glob(act.tests.EXAMPLE_NEON_POSITION)
 
-    obj = act.io.neon.read_neon_csv(data_file)
-    assert len(obj['time'].values) == 17280
-    assert 'time' in obj
-    assert 'tempSingleMean' in obj
-    assert obj['tempSingleMean'].values[0] == -0.6003
+    ds = act.io.neon.read_neon_csv(data_file)
+    assert len(ds['time'].values) == 17280
+    assert 'time' in ds
+    assert 'tempSingleMean' in ds
+    assert ds['tempSingleMean'].values[0] == -0.6003
 
-    obj = act.io.neon.read_neon_csv(data_file, variable_files=variable_file, position_files=position_file)
-    assert obj['northOffset'].values == -5.79
-    assert obj['tempSingleMean'].attrs['units'] == 'celsius'
-    assert 'lat' in obj
-    assert obj['lat'].values == 71.282425
+    ds = act.io.neon.read_neon_csv(data_file, variable_files=variable_file, position_files=position_file)
+    assert ds['northOffset'].values == -5.79
+    assert ds['tempSingleMean'].attrs['units'] == 'celsius'
+    assert 'lat' in ds
+    assert ds['lat'].values == 71.282425
